@@ -32,7 +32,7 @@ class BillingException(Exception):
 class Client(object):
     def __init__(self, apikey, apiserver = API_SERVER):
         self.apikey = apikey
-        self.apiserver = apiserver
+        self.apiserver = apiserver.rstrip('/')
 
     def call(self, function, **kw):
         try:
@@ -57,6 +57,14 @@ class Client(object):
     def recurring_delete(self, id):
         return self.call('recurring_delete', id = id)
 
+    def recurring_mod_resource(self, id, resource, delta):
+        """
+        id - recurring invoice ID
+        resource - ID of resource to be modified
+        delta - delta to modify by
+        """
+        return self.call('recurring_mod_resource', id = id, resource = resource, delta = delta)
+
     def invoice_add(self, **kw):
         return self.call('invoice_add', **kw)
 
@@ -81,8 +89,9 @@ class Client(object):
     def customer_balance_multi(self, **kw):
         return self.call('customer_balance_multi', **kw)
 
+    def customer_invoices(self, **kw):
+        return self.call('customer_invoices', **kw)
+
     def sso_token(self, **kw):
         return self.call('sso_token', **kw)
 
-    def customer_invoices(self, **kw):
-        return self.call('customer_invoices', **kw)
\ No newline at end of file
